@@ -1,27 +1,14 @@
-/*  This file is part of the KDE libraries
- *  Copyright 2012 David Faure <faure+bluesystems@kde.org>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2012 David Faure <faure+bluesystems@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "frameworkintegrationplugin.h"
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
-#include <knotification.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <KNotification>
 
 #include <qplugin.h>
 #include <QDebug>
